# Changelog

## [0.6.0](https://github.com/SoferAi/soferai-py/compare/v0.5.0...v0.6.0) (2025-03-13)


### Features

* **fern:** regeneration march 12, 2025 ([#113](https://github.com/SoferAi/soferai-py/issues/113)) ([fae6c38](https://github.com/SoferAi/soferai-py/commit/fae6c38047a08a485b6e27a0b24b44dac9abc0d2))
* **fern:** regeneration march 3, 2025 ([#104](https://github.com/SoferAi/soferai-py/issues/104)) ([017061f](https://github.com/SoferAi/soferai-py/commit/017061fcd4c1b3484879f87482928c2daabd07f1))

## [0.5.0](https://github.com/SoferAi/soferai-py/compare/v0.4.0...v0.5.0) (2025-02-13)


### Features

* basic tests ([#78](https://github.com/SoferAi/soferai-py/issues/78)) ([e9d044e](https://github.com/SoferAi/soferai-py/commit/e9d044ee45a1697dbd29133a635fbe128b832cdc))
* **fern:** regeneration february 9, 2025 ([#66](https://github.com/SoferAi/soferai-py/issues/66)) ([a3e6852](https://github.com/SoferAi/soferai-py/commit/a3e6852ecd8ed72c80bf4477a30f274ed3708a0a))
* **fern:** regeneration january 27, 2025 ([#50](https://github.com/SoferAi/soferai-py/issues/50)) ([ebcad2f](https://github.com/SoferAi/soferai-py/commit/ebcad2f72fd38673f2e7bbb0188305d7ee450648))

## [0.4.0](https://github.com/SoferAi/soferai-py/compare/v0.3.0...v0.4.0) (2025-01-27)


### Features

* **fern:** regeneration december 31, 2024 ([#26](https://github.com/SoferAi/soferai-py/issues/26)) ([9d1d490](https://github.com/SoferAi/soferai-py/commit/9d1d4903ade5955ee6bbc0a54a194abc665504ce))
* **fern:** regeneration january 22, 2025 ([#35](https://github.com/SoferAi/soferai-py/issues/35)) ([e511f48](https://github.com/SoferAi/soferai-py/commit/e511f48c6a28b450eb5f1fa422f6f2721a3c9686))
* **fern:** regeneration january 27, 2025 ([#48](https://github.com/SoferAi/soferai-py/issues/48)) ([042cf1a](https://github.com/SoferAi/soferai-py/commit/042cf1a48b27c603e9536bbdee2d3c4773b014be))


### Bug Fixes

* add renovate.json to fernignore ([#47](https://github.com/SoferAi/soferai-py/issues/47)) ([99591ed](https://github.com/SoferAi/soferai-py/commit/99591ed53c21349b0ab9c0b7b77b527b72b253a7))

## [0.3.0](https://github.com/SoferAi/soferai-py/compare/v0.2.0...v0.3.0) (2024-12-24)


### Features

* **fern:** regeneration december 24, 2024 ([#20](https://github.com/SoferAi/soferai-py/issues/20)) ([e579042](https://github.com/SoferAi/soferai-py/commit/e579042f7c91c14cd9fa5f41eaf5363d8e1f1b8f))


### Bug Fixes

* set httpx dependency to something supabase can handle ([#22](https://github.com/SoferAi/soferai-py/issues/22)) ([c626286](https://github.com/SoferAi/soferai-py/commit/c626286dc098f44c6af6c354efe876180c726b8b))
* update ci and fernignore ([#18](https://github.com/SoferAi/soferai-py/issues/18)) ([53b5a55](https://github.com/SoferAi/soferai-py/commit/53b5a55ff5fe3395d8041fb604f1f35459ea3993))

## [0.2.0](https://github.com/SoferAi/soferai-py/compare/v0.1.0...v0.2.0) (2024-12-23)


### Features

* **🌿:** regenerate ([#14](https://github.com/SoferAi/soferai-py/issues/14)) ([82a04fb](https://github.com/SoferAi/soferai-py/commit/82a04fb7c6bdbdb9769981fb75be7a05b525fc7f))


### Bug Fixes

* add stuff to fernignore ([#12](https://github.com/SoferAi/soferai-py/issues/12)) ([52aa5a9](https://github.com/SoferAi/soferai-py/commit/52aa5a91c3e89cd1e0c8d42b536b90ac45653fac))

## 0.1.0 (2024-12-23)


### Features

* **🌿:** fern regeneration 12-23-2024 ([#6](https://github.com/SoferAi/soferai-py/issues/6)) ([931cb07](https://github.com/SoferAi/soferai-py/commit/931cb074f5a606ee081ab7c1ec43194c889af82c))
* basic example ([686b65b](https://github.com/SoferAi/soferai-py/commit/686b65bfe40365c30200f3d9b8f716b5bfdd91cc))
* **ci:** add release please and fernignore ([#3](https://github.com/SoferAi/soferai-py/issues/3)) ([b2a5aae](https://github.com/SoferAi/soferai-py/commit/b2a5aae3a2c41d74dee66687252cb5c9e62bd25c))
